@@ -47,17 +47,18 @@ MNP <- function(data, MC = 999, typeI = 0.05, nbCPU = 1, variable_names = NULL,
         stop("The number of elements in variable_names must be the number of columns in data")
       }
     }
-
+    cat("Computation of the scan statistic \n")
     rank_data <- SpatialNP::spatial.rank(data, shape = TRUE)
     index <- multi_WMW(rank_data, matrix_clusters)
-
+    cat("---Done--- \n")
+    cat("Estimation of the statistical significance \n")
     nb_clusters <- ncol(matrix_clusters)
     nb_sites <- nrow(matrix_clusters)
 
     num_cores <- detectCores()
 
     if(nbCPU <=1 | num_cores<2){
-      results <- lapply(1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters))
+      results <- pblapply(1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters))
     }else{
       if(num_cores < nbCPU){
         nbCPU <- num_cores
@@ -65,18 +66,19 @@ MNP <- function(data, MC = 999, typeI = 0.05, nbCPU = 1, variable_names = NULL,
 
       if(.Platform$OS.type == "windows"){
         cl <- makeCluster(nbCPU)
-        results <- parLapply(cl, 1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters))
+        results <- pblapply(1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters), cl = cl)
         stopCluster(cl)
 
       }else{
-        results <- mclapply(1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters), mc.cores = nbCPU)
+        results <- pblapply(1:MC, function(i) multi_WMW(rank_data[permutations[i,],], matrix_clusters), cl = nbCPU)
       }
 
     }
     results <- matrix(unlist(results), ncol = nb_clusters, byrow = TRUE)
     stat_MC <- rowMaxs(results)
     pvals <- sapply(1:nb_clusters, function(j) (length(which(stat_MC >= index[j]))+1)/(MC+1))
-
+    cat("---Done--- \n")
+    cat("Finalization \n")
     index_clusters_temp <- which(pvals <= typeI)
 
     finalization <- FinScan(index_clusters_temp, index, filtering_post, type_minimaxi_post, mini_post, maxi_post, nb_sites, matrix_clusters, radius, areas, centres, pvals)
@@ -141,16 +143,17 @@ MG <- function(data, MC = 999, typeI = 0.05, nbCPU = 1, variable_names = NULL, i
       }
     }
 
-
+    cat("Computation of the scan statistic \n")
     index <- multi_gaussian(data, matrix_clusters)
-
+    cat("---Done--- \n")
+    cat("Estimation of the statistical significance \n")
     nb_clusters <- ncol(matrix_clusters)
     nb_sites <- nrow(matrix_clusters)
 
     num_cores <- detectCores()
 
     if(nbCPU <=1 | num_cores <2){
-      results <- lapply(1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters))
+      results <- pblapply(1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters))
     }else{
 
       if(num_cores < nbCPU){
@@ -159,18 +162,19 @@ MG <- function(data, MC = 999, typeI = 0.05, nbCPU = 1, variable_names = NULL, i
 
       if(.Platform$OS.type == "windows"){
         cl <- makeCluster(nbCPU)
-        results <- parLapply(cl, 1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters))
+        results <- pblapply(1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters),cl=cl)
         stopCluster(cl)
 
       }else{
-        results <- mclapply(1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters), mc.cores = nbCPU)
+        results <- pblapply(1:MC, function(i) multi_gaussian(data[permutations[i,],], matrix_clusters), cl = nbCPU)
       }
 
     }
     results <- matrix(unlist(results), ncol = nb_clusters, byrow = TRUE)
     stat_MC <- rowMins(results)
     pvals <- sapply(1:nb_clusters, function(j) (length(which(stat_MC <= index[j]))+1)/(MC+1))
-
+    cat("---Done--- \n")
+    cat("Finalization \n")
     index_clusters_temp <- which(pvals <= typeI)
 
     finalization <- FinScan(index_clusters_temp, index, filtering_post, type_minimaxi_post, mini_post, maxi_post, nb_sites, matrix_clusters, radius, areas, centres, pvals, maximize = FALSE)
